@@ -7,7 +7,7 @@ from matplotlib import pyplot as plt
 from mrftools import DictionaryParameters, SequenceParameters
 
 class Simulation: 
-    def __init__(self,sequenceParameters, dictionaryParameters, name="", numTimepoints = -1, phaseRange=(-2*np.pi, 2*np.pi), numSpins=1, fullResults=[], truncationMatrix=[], truncatedResults=[]):
+    def __init__(self,sequenceParameters, dictionaryParameters, name="", numTimepoints = -1, phaseRange=(-2*np.pi, 2*np.pi), numSpins=1, results=[], truncationMatrix=[], truncatedResults=[]):
         self.sequenceParameters = sequenceParameters
         self.dictionaryParameters = dictionaryParameters
         if numTimepoints == -1:
@@ -15,7 +15,7 @@ class Simulation:
         self.numTimepoints = numTimepoints
         self.phaseRange = phaseRange
         self.numSpins = numSpins
-        self.fullResults = fullResults
+        self.results = results
         self.truncationMatrix = truncationMatrix
         self.truncatedResults = truncatedResults
         if not name:
@@ -126,7 +126,7 @@ class Simulation:
         print("Simulating " + str(numBatches) + " batch(s) of " + str(dictEntriesPerBatch) + " dictionary entries")
         Mxy = np.zeros((self.numTimepoints, len(self.dictionaryParameters.entries)), np.complex128)
         for i in range(numBatches):
-            print("Batch: " + str(i))
+            print("Starting Batch: " + str(i))
             firstDictEntry = i*dictEntriesPerBatch
             lastDictEntry = firstDictEntry+dictEntriesPerBatch
             T1s.clear();T2s.clear();B1s.clear()
@@ -137,10 +137,11 @@ class Simulation:
             Mx0,My0,Mz0 = self.ExecuteNumbaSimulation(self.numTimepoints, np.asarray(T1s),np.asarray(T2s),np.asarray(B1s),np.asarray(TRs),np.asarray(TEs),np.asarray(FAs),phaseValues)
             Mx,My,Mz = self.ParallizedMeans(Mx0,My0,Mz0)
             Mxy[:,firstDictEntry:lastDictEntry] = Mx+(My*1j)
-        self.fullResults = Mxy
+        self.results = Mxy
+        return self.results
 
     def CalculateSVD(self, truncationNumber):
-        dictionary = np.transpose(self.fullResults)
+        dictionary = self.results.transpose()
         dictionaryNorm = np.sqrt(np.sum(np.power(np.abs(dictionary[:,:]),2),1))
         dictionaryShape = np.shape(dictionary)
         normalizedDictionary = np.zeros_like(dictionary)
@@ -174,34 +175,33 @@ class Simulation:
                 simulation["sequenceParameters"] = outfile["/sequenceParameters/"+self.sequenceParameters.name]
                 self.dictionaryParameters.Export(filename, force)
                 simulation["dictionaryParameters"] = outfile["/dictionaryParameters/"+self.dictionaryParameters.name]
-                if includeFullResults:
-                    simulation["fullResults"] = self.fullResults
+                if(includeFullResults):
+                    simulation["results"] = self.results
                 else:
-                    simulation["fullResults"] = []
-                if includeSVDResults:
+                    simulation["results"] = []
+                if(includeFullResults):
                     simulation["truncationMatrix"] = self.truncationMatrix
                     simulation["truncatedResults"] = self.truncatedResults
                 else:
                     simulation["truncationMatrix"] = []
                     simulation["truncatedResults"] = []
+
                 outfile.close()
         else:
             print("Input is not a .mrf file")
 
-    def GetAverageTimecourse(self, dictionaryEntryNumbers:list):
-        np.shape(np.average(self.fullResults[:,dictionaryEntryNumbers], 1))
-
     def Plot(self, numTimepoints=-1, dictionaryEntryNumbers=[], plotTruncated=False):
         if numTimepoints == -1:
             numTimepoints = len(self.sequenceParameters.timepoints)
         if dictionaryEntryNumbers == []:
             dictionaryEntryNumbers = [int(len(self.dictionaryParameters.entries)/2)]
         ax = plt.subplot(1,1,1)
-        for entry in dictionaryEntryNumbers:
-            if(plotTruncated):
+        if not plotTruncated:
+            for entry in dictionaryEntryNumbers:
+                plt.plot(abs(self.results[:,entry]), label=str(self.dictionaryParameters.entries[entry]))
+        else:
+            for entry in dictionaryEntryNumbers:
                 plt.plot(abs(self.truncatedResults[:,entry]), label=str(self.dictionaryParameters.entries[entry]))
-            else:
-                plt.plot(abs(self.fullResults[:,entry]), label=str(self.dictionaryParameters.entries[entry]))
         ax.legend()
 
     @staticmethod
@@ -213,14 +213,14 @@ class Simulation:
             simulationNumTimepoints = simulationGroup.attrs.get("numTimepoints")
             simulationPhaseRange = simulationGroup.attrs.get("phaseRange")
             simulationNumSpins = simulationGroup.attrs.get("numSpins")
-            simulationFullResults = simulationGroup["fullResults"][:]
+            simulationResults = simulationGroup["results"][:]
             simulationTruncationMatrix = simulationGroup["truncationMatrix"][:]
             simulationTruncatedResults = simulationGroup["truncatedResults"][:]
             sequenceParametersGroup = simulationGroup["sequenceParameters"]
             importedSequenceParameters = SequenceParameters(sequenceParametersGroup.attrs.get("name"), sequenceParametersGroup["timepoints"][:])
             dictionaryParametersGroup = simulationGroup["dictionaryParameters"]
             importedDictionaryParameters = DictionaryParameters(dictionaryParametersGroup.attrs.get("name"), dictionaryParametersGroup["entries"][:])
-            new_simulation = Simulation(importedSequenceParameters, importedDictionaryParameters, simulationName, simulationNumTimepoints, simulationPhaseRange, simulationNumSpins, simulationFullResults, simulationTruncationMatrix, simulationTruncatedResults)
+            new_simulation = Simulation(importedSequenceParameters, importedDictionaryParameters, simulationName, simulationNumTimepoints, simulationPhaseRange, simulationNumSpins, simulationResults, simulationTruncationMatrix, simulationTruncatedResults)
             infile.close()
             return new_simulation
         else:
